@@ -10,10 +10,15 @@
 
 #include "client_p.h"
 #include <QMap>
+#include <memory>
 
-namespace Sonnet {
+class Hunspell;
+
+namespace Sonnet
+{
 class SpellerPlugin;
 }
+
 using Sonnet::SpellerPlugin;
 
 class HunspellClient : public Sonnet::Client
@@ -41,6 +46,8 @@ public:
 
 private:
     QMap<QString, QString> m_languagePaths;
+    QMap<QString, std::weak_ptr<Hunspell>> m_hunspellCache;
+    QMap<QString, QString> m_languageAliases;
 };
 
 #endif
